@@ -18,7 +18,7 @@ class Notification(InstaBaseObject):
         return False
 
     def __repr__(self) -> str:
-        return f'Notification<{self.type}, {self.from_user}>'
+        return f'Notification<{self.type} | {self.from_user}>'
 
     def __lt__(self, o) -> bool:
         if self.timestamp < o.timestamp:
